@@ -3,7 +3,7 @@ from rest_framework.filters import BaseFilterBackend
 
 class ValidatedResourcesByStepFilterBackend(BaseFilterBackend):
     def filter_queryset(self, request, queryset, view):
-        return queryset.filter(steps__in=view.kwargs['id'], review__status='validated')
+        return queryset.filter(steps__urlid__icontains=view.kwargs['id'], review__status='validated')
 
 
 class PendingResourceFilterBackend(BaseFilterBackend):
