@@ -373,7 +373,7 @@ def update_review(sender, instance, created, **kwargs):
         return False
 
     if not created:
-        if instance.resource:
+        if getattr(settings, 'UPDATE_REVIEW', True) and instance.resource is not None:
             resource = instance.resource
             if instance.status == 'validated':
                 subject = 'The resource you submitted has been validated !'
