@@ -4,11 +4,9 @@ from .models import Resource, Type, Format, LearningOutcome, Step, Field, Sharin
 # A translation option is a class that declares which fields of a model to translate
 # registering it with the translator creates duplicate columns for each language, in the database
 # (https://django-modeltranslation.readthedocs.io/en/latest/registration.html#changes-automatically-applied-to-the-model-class)
-
+@register(Resource)
 class ResourceTranslationOptions(TranslationOptions):
     fields = ('description', 'name')
-    # required_languages = ('en', 'fr')
-    # required_languages = {'de': ('title', 'text'), 'default': ('title',)} - fine-grained control
 
 @register(Type)
 class TypeTranslationOptions(TranslationOptions):
